powered by
Remove the first instance of a newline from a string
nix_first_newline(s)
A string with the first instance of a newline removed.
(character) A string
nix_first_newline("onetwo\nthree\nfour") # Nothing to remove nix_first_newline("fivesixseven")
Run the code above in your browser using DataLab